@@ -392,31 +392,6 @@ class Deserializer(object):
             # Old SoL 2 dump
             del schampionship['prizefactor']
 
-        if 'previous' in schampionship:
-            try:
-                psidx = schampionship['previous'] - 1
-            except TypeError:
-                # Old SoL 2 dump
-                psidx = None
-                psdesc = schampionship['previous']
-                for i, s in enumerate(self.championships):
-                    if s.description == psdesc and s.club is club:
-                        psidx = i
-                        break
-
-            if psidx is None:
-                try:
-                    pchampionship = query(Championship).filter_by(
-                        description=psdesc, idclub=club.idclub).one()
-                except NoResultFound:
-                    logger.warning('Could not find previous championship "%s" for %r',
-                                   psdesc, championship)
-                    del schampionship['previous']
-                else:
-                    schampionship['previous'] = pchampionship
-            else:
-                schampionship['previous'] = self.championships[psidx]
-
         if championship is None:
             if not 'owner' in schampionship:
                 schampionship['idowner'] = self.idowner
@@ -662,19 +637,13 @@ class Deserializer(object):
                 pending_owned_instances = []
 
                 for simple in data.get('clubs', []):
-                    if 'owner' in simple:
-                        owner = simple.pop('owner')
-                    else:
-                        owner = None
+                    owner = simple.pop('owner', None)
                     club = self.addClub(simple)
                     if owner is not None:
                         pending_owned_instances.append((club, owner))
 
                 for simple in data.get('players', []):
-                    if 'owner' in simple:
-                        owner = simple.pop('owner')
-                    else:
-                        owner = None
+                    owner = simple.pop('owner', None)
                     player = self.addPlayer(simple)
                     if owner is not None:
                         pending_owned_instances.append((player, owner))
@@ -690,8 +659,37 @@ class Deserializer(object):
                 else:
                     championships = data.get('championships', [])
 
+                pending_chained_instances = []
+
                 for simple in championships:
-                    self.addChampionship(simple)
+                    previous = simple.pop('previous', None)
+                    cship = self.addChampionship(simple)
+                    if previous is not None:
+                        pending_chained_instances.append((cship, previous))
+
+                for instance, previous in pending_chained_instances:
+                    try:
+                        previdx = previous - 1
+                    except TypeError:
+                        # Old SoL 2 dump
+                        previdx = None
+                        for i, s in enumerate(self.championships):
+                            if s.description == previous and s.club is instance.club:
+                                previdx = i
+                                break
+
+                        if previdx is None:
+                            try:
+                                pchampionship = self.session.query(Championship).filter_by(
+                                    description=previous, idclub=instance.club.idclub).one()
+                            except NoResultFound:
+                                logger.warning('Could not find previous championship "%s"'
+                                               ' for %r', previous, instance)
+                            else:
+                                instance.previous = pchampionship
+
+                    if previdx is not None:
+                        instance.previous = self.championships[previdx]
 
                 for simple in data.get('ratings', []):
                     self.addRating(simple)
