@@ -81,8 +81,8 @@ class Championship(GloballyUnique, Base):
                   hint=N_('Method used to assign final prizes.'),
                   dictionary=dict(
                       asis=N_('No final prizes'),
-                      fixed=N_('Fixed prizes: 18,16,14,13...'),
-                      fixed40=N_('Fixed prizes: 1000,900,800,750...'),
+                      fixed=N_('Fixed prizes: 18,16,14,13…'),
+                      fixed40=N_('Fixed prizes: 1000,900,800,750…'),
                       millesimal=N_('Classic millesimal prizes'),
                       centesimal=N_('Centesimal prizes'))))
     """Kind of prize-giving.
@@ -98,7 +98,7 @@ class Championship(GloballyUnique, Base):
 
     `fixed`
       means the usual way, that is 18 points to the winner, 16 to the second, 14 to the third,
-      13 to the fourth, ..., 1 point to the 16th, 0 points after that;
+      13 to the fourth, …, 1 point to the 16th, 0 points after that;
 
     `fixed40`
       similar to `fixed`, but applied to best fourty scores starting from 1000:
