@@ -100,8 +100,8 @@ class Club(GloballyUnique, Base):
                   hint=N_('Default method used to assign final prizes.'),
                   dictionary=dict(
                       asis=N_('Simple tourneys, no special prizes'),
-                      fixed=N_('Fixed prizes: 18,16,14,13...'),
-                      fixed40=N_('Fixed prizes: 1000,900,800,750...'),
+                      fixed=N_('Fixed prizes: 18,16,14,13…'),
+                      fixed40=N_('Fixed prizes: 1000,900,800,750…'),
                       millesimal=N_('Classic millesimal prizes'))))
     """Kind of prize-giving, used as default value for the corresponding
     field when creating a new championship.
@@ -114,7 +114,7 @@ class Club(GloballyUnique, Base):
 
     `fixed`
       means the usual way, that is 18 points to the winner, 16 to the
-      second, 14 to the third, 13 to the fourth, ..., 1 point to the
+      second, 14 to the third, 13 to the fourth, …, 1 point to the
       16th, 0 points after that;
 
     `fixed40`
