@@ -296,7 +296,7 @@ class Rating(GloballyUnique, Base):
         :param competitor: a Competitor instance
 
         This is needed because someone use a concrete player as Phantom,
-        to customize its name (not everybody have a good sense of humor...)
+        to customize its name (not everybody have a good sense of humor…)
         """
 
         return (competitor is None
