@@ -158,8 +158,8 @@ class Tourney(GloballyUnique, Base):
         boolean_t,
         nullable=False,
         default=False,
-        info=dict(label=N_('Prized'),
-                  hint=N_('Whether the final prizes has been assigned.')))
+        info=dict(label=N_('Closed'),
+                  hint=N_('Whether the final prizes have been assigned.')))
     """Whether the tourney is closed, and final prizes updated."""
 
     phantomscore = Column(
