@@ -1505,7 +1505,7 @@ class Badges(object):
 
         c.setFont(cardsmall_style.fontName, cardsmall_style.fontSize, cardsmall_style.leading)
 
-        c.drawCentredString(1.8*cm, self.height-1*cm, gettext('You met...'))
+        c.drawCentredString(1.8*cm, self.height-1*cm, gettext('You met…'))
         c.drawString(0.3*cm, self.height-1.25*cm, gettext('Opponent'))
 
         # TRANSLATORS: this is the "score of this player" in the badge
@@ -1542,7 +1542,7 @@ class Badges(object):
         c.drawString(3.8*cm, self.height-1.25*cm,
                      gettext('Competitor'))
         if self.tourney.championship.prizes == 'asis':
-            # TRANSLATORS: this is the final points in the badge
+            # TRANSLATORS: this is the points in the badge
             pts = gettext('pts')
             c.drawRightString(7.6*cm, self.height-1.25*cm, pts)
             # TRANSLATORS: this is the bucholz in the badge
@@ -1562,7 +1562,7 @@ class Badges(object):
                 c.drawRightString(8.0*cm, h, str(ctor.bucholz))
                 c.drawRightString(8.4*cm, h, str(ctor.netscore))
         else:
-            # TRANSLATORS: this is the final points in the badge
+            # TRANSLATORS: this is the points in the badge
             pts = gettext('pts')
             c.drawRightString(6.9*cm, self.height-1.25*cm, pts)
             # TRANSLATORS: this is the bucholz in the badge
