@@ -280,7 +280,7 @@ Ext.define('SoL.module.Championships.Actions', {
             resizable: false,
             tools: [{
                 type: 'help',
-                tooltip: _('Show help'),
+                tooltip: _('Show user manual section.'),
                 callback: function() {
                     var whsize = desktop.getReasonableWindowSize(800, 640);
                     var wh = Ext.create('SoL.window.Help', {
@@ -425,7 +425,7 @@ Ext.define('SoL.module.Championships', {
                     height: size.height,
                     tools: [{
                         type: 'help',
-                        tooltip: _('Show help'),
+                        tooltip: _('Show user manual section.'),
                         callback: function() {
                             var whsize = desktop.getReasonableWindowSize(800, 640);
                             var wh = Ext.create('SoL.window.Help', {
