@@ -288,7 +288,7 @@ Ext.define('SoL.module.Clubs.Actions', {
                         fieldLabel: '',
                         labelWidth: 0,
                         buttonOnly: true,
-                        buttonText: _('Change emblem...'),
+                        buttonText: _('Change emblem…'),
                         style: 'text-align: center;',
                         listeners: {
                             afterrender: function(fld) {
@@ -362,7 +362,7 @@ Ext.define('SoL.module.Clubs.Actions', {
             resizable: false,
             tools: [{
                 type: 'help',
-                tooltip: _('Show help'),
+                tooltip: _('Show user manual section.'),
                 callback: function() {
                     var whsize = desktop.getReasonableWindowSize(800, 640);
                     var wh = Ext.create('SoL.window.Help', {
@@ -506,7 +506,7 @@ Ext.define('SoL.module.Clubs', {
                     height: size.height,
                     tools: [{
                         type: 'help',
-                        tooltip: _('Show help'),
+                        tooltip: _('Show user manual section.'),
                         callback: function() {
                             var whsize = desktop.getReasonableWindowSize(800, 640);
                             var wh = Ext.create('SoL.window.Help', {
