@@ -274,7 +274,7 @@ Ext.define('SoL.module.Players.Actions', {
                         fieldLabel: '',
                         labelWidth: 0,
                         buttonOnly: true,
-                        buttonText: _('Change portrait...'),
+                        buttonText: _('Change portrait…'),
                         style: 'text-align: center;',
                         listeners: {
                             afterrender: function(fld) {
@@ -348,7 +348,7 @@ Ext.define('SoL.module.Players.Actions', {
             resizable: false,
             tools: [{
                 type: 'help',
-                tooltip: _('Show help'),
+                tooltip: _('Show user manual section.'),
                 callback: function() {
                     var whsize = desktop.getReasonableWindowSize(800, 640);
                     var wh = Ext.create('SoL.window.Help', {
@@ -622,7 +622,7 @@ Ext.define('SoL.module.Players', {
                     height: size.height,
                     tools: [{
                         type: 'help',
-                        tooltip: _('Show help'),
+                        tooltip: _('Show user manual section.'),
                         callback: function() {
                             var whsize = desktop.getReasonableWindowSize(800, 640);
                             var wh = Ext.create('SoL.window.Help', {
@@ -797,7 +797,7 @@ Ext.define('SoL.module.Players.MergeTarget', {
                 if('yes' == response) {
                     Ext.create("MP.window.Notification", {
                         position: 'br',
-                        html: _('Merging selected players...'),
+                        html: _('Merging selected players…'),
                         title: _('Please wait'),
                         iconCls: 'waiting-icon'
                     }).show();
