@@ -179,7 +179,7 @@ Ext.define('SoL.module.RatedPlayers', {
                     height: size.height,
                     tools: [{
                         type: 'help',
-                        tooltip: _('Show help'),
+                        tooltip: _('Show user manual section.'),
                         callback: function() {
                             var whsize = desktop.getReasonableWindowSize(800, 640);
                             var wh = Ext.create('SoL.window.Help', {
