@@ -91,7 +91,7 @@ Ext.define('SoL.module.Ratings.Actions', {
 
                 Ext.create("MP.window.Notification", {
                     position: 'br',
-                    html: _('Recomputing...'),
+                    html: _('Recomputing…'),
                     title: _('Please wait'),
                     iconCls: 'waiting-icon'
                 }).show();
@@ -318,7 +318,7 @@ Ext.define('SoL.module.Ratings.Actions', {
             resizable: false,
             tools: [{
                 type: 'help',
-                tooltip: _('Show help'),
+                tooltip: _('Show user manual section.'),
                 callback: function() {
                     var whsize = desktop.getReasonableWindowSize(800, 640);
                     var wh = Ext.create('SoL.window.Help', {
@@ -436,7 +436,7 @@ Ext.define('SoL.module.Ratings', {
                     height: size.height,
                     tools: [{
                         type: 'help',
-                        tooltip: _('Show help'),
+                        tooltip: _('Show user manual section.'),
                         callback: function() {
                             var whsize = desktop.getReasonableWindowSize(800, 640);
                             var wh = Ext.create('SoL.window.Help', {
