@@ -130,7 +130,7 @@ Ext.define('SoL.module.Tourneys.Actions', {
                         if('yes' == response) {
                             Ext.create("MP.window.Notification", {
                                 position: 'br',
-                                html: _('Replicating selected tourney...'),
+                                html: _('Replicating selected tourney…'),
                                 title: _('Please wait'),
                                 iconCls: 'waiting-icon'
                             }).show();
@@ -387,7 +387,7 @@ Ext.define('SoL.module.Tourneys.Actions', {
             resizable: false,
             tools: [{
                 type: 'help',
-                tooltip: _('Show help'),
+                tooltip: _('Show user manual section.'),
                 callback: function() {
                     var whsize = desktop.getReasonableWindowSize(800, 640);
                     var wh = Ext.create('SoL.window.Help', {
@@ -593,7 +593,7 @@ Ext.define('SoL.module.Tourneys', {
                     height: size.height,
                     tools: [{
                         type: 'help',
-                        tooltip: _('Show help'),
+                        tooltip: _('Show user manual section.'),
                         callback: function() {
                             var whsize = desktop.getReasonableWindowSize(800, 640);
                             var wh = Ext.create('SoL.window.Help', {
