@@ -39,7 +39,7 @@ Ext.define('SoL.view.Matches.Actions', {
             tooltip: _('Create next round.'),
             iconCls: 'new-turn-icon',
             disabled: tourney.currentturn != tourney.rankedturn,
-            hidden: me.component.readOnly,
+            hidden: tourney.readOnly,
             scope: me.component,
             handler: me.component.newTurn
         }));
@@ -50,7 +50,7 @@ Ext.define('SoL.view.Matches.Actions', {
             tooltip: _('Create final round.'),
             iconCls: 'new-turn-icon',
             disabled: tourney.currentturn != tourney.rankedturn,
-            hidden: me.component.readOnly || !tourney.finals,
+            hidden: tourney.readOnly || !tourney.finals,
             scope: me.component,
             handler: me.component.finalTurn
         }));
@@ -60,8 +60,8 @@ Ext.define('SoL.view.Matches.Actions', {
             text: _('Show clock'),
             tooltip: _('Show an alarm clock for the current round.'),
             iconCls: 'alarm-clock-icon',
-            disabled: me.component.readOnly,
-            hidden: me.component.readOnly,
+            disabled: tourney.readOnly,
+            hidden: tourney.readOnly,
             handler: function() {
                 var url = '/tourney/clock?idtourney=' + tourney.idtourney;
                 window.open(url, "_blank");
@@ -73,8 +73,8 @@ Ext.define('SoL.view.Matches.Actions', {
             text: _('Scorecards'),
             tooltip: _('Print current round scorecards.'),
             iconCls: 'print-icon',
-            disabled: me.component.readOnly,
-            hidden: me.component.readOnly,
+            disabled: tourney.readOnly,
+            hidden: tourney.readOnly,
             handler: function() {
                 var url = '/pdf/scorecards/' + tourney.idtourney;
                 window.location.assign(url);
@@ -109,8 +109,8 @@ Ext.define('SoL.view.Matches.Actions', {
             text: _('Matches'),
             tooltip: _('Print next round matches.'),
             iconCls: 'print-icon',
-            disabled: me.component.readOnly,
-            hidden: me.component.readOnly,
+            disabled: tourney.readOnly,
+            hidden: tourney.readOnly,
             handler: function() {
                 var url = '/pdf/matches/' + tourney.idtourney;
                 window.location.assign(url);
@@ -308,7 +308,6 @@ Ext.define('SoL.view.Matches', {
                 lbar: [],
                 noAddAndDelete: true,
                 noBottomToolbar: true,
-                noSaveAndResetActions: config.tourney.prized,
                 noFilterbar: true,
                 pageSize: 999,
                 plugins: [
@@ -316,7 +315,6 @@ Ext.define('SoL.view.Matches', {
                         module: me
                     })
                 ],
-                readOnly: config.tourney.prized,
                 saveChangesURL: '/bio/saveChanges',
                 sorters: ['turn', 'board'],
                 title: (config.tourney.currentturn === 0
@@ -382,24 +380,21 @@ Ext.define('SoL.view.Matches', {
         }
     },
 
-    initComponent: function() {
+    initEvents: function() {
         var me = this;
 
-        me.callParent(arguments);
+        me.callParent();
 
-        if(!me.readOnly) {
-            me.on("beforeedit", function(editor, event) {
-                //jsl:unused editor
-                var rec = event.record;
-                var cturn = me.module.tourney.currentturn;
-                var phantom = rec.get("idcompetitor2") === null;
-                return (!phantom && rec.get("turn") == cturn);
-            });
-        } else {
-            this.on("beforeedit", function() {
+        me.on("beforeedit", function(editor, event) {
+            var tourney = me.module.tourney;
+
+            if(tourney.prized)
                 return false;
-            });
-        }
+
+            var rec = event.record;
+            var phantom = rec.get("idcompetitor2") === null;
+            return (!phantom && rec.get("turn") == tourney.currentturn);
+        });
 
         // Install a KeyMap on the grid that allows jumping to a given record
         // (and eventually start editing its score1 column) simply by digiting
@@ -673,22 +668,30 @@ Ext.define('SoL.view.Matches', {
     updateActions: function() {
         var me = this;
         var tourney = me.module.tourney;
+        var pca = me.findActionById('print_cards');
         var nta = me.findActionById('new_turn');
         var fta = me.findActionById('final_turn');
         var clk = me.findActionById('show_clock');
+        var save = me.findActionById('save');
+        var restore = me.findActionById('restore');
         var lbar = me.child('toolbar[dock="left"]');
 
+        pca.setHidden(tourney.prized || tourney.readOnly);
         nta.setDisabled(!tourney.partecipants ||
                         (tourney.currentturn > 0 && tourney.currentturn!=tourney.rankedturn));
-        nta.setHidden(tourney.prized || me.readOnly);
+        nta.setHidden(tourney.prized || tourney.readOnly);
         fta.setDisabled(!tourney.partecipants || tourney.finalturns ||
                         (tourney.currentturn > 0 && tourney.currentturn!=tourney.rankedturn));
-        fta.setHidden(tourney.prized || !tourney.finals || me.readOnly);
-        clk.setHidden(tourney.prized || me.readOnly);
+        fta.setHidden(tourney.prized || !tourney.finals || tourney.readOnly);
+        clk.setDisabled(tourney.prized || tourney.readOnly);
+        clk.setHidden(tourney.prized || tourney.readOnly);
+        save.setHidden(tourney.prized || tourney.readOnly);
+        restore.setHidden(tourney.prized || tourney.readOnly);
         lbar.cascade(function(btn) {
             if(btn.xtype == 'tbseparator' || btn.iconCls == 'icon-cross') {
-                btn.setVisible((!tourney.prized && tourney.currentturn > 0) ||
-                               tourney.finalturns);
+                btn.setVisible(!tourney.readOnly
+                               && ((!tourney.prized && tourney.currentturn > 0)
+                                   || tourney.finalturns));
             }
         });
     }
