@@ -94,7 +94,7 @@ Ext.define('SoL.view.Ranking.Actions', {
 
         me.prizegivingAction = this.addAction(new Ext.Action({
             itemId: ids.PRIZE_GIVING_ACTION,
-            text: tprized ? _('Reset prizes') : _('Prize'),
+            text: tprized ? _('Reset prizes') : _('Assign prizes'),
             hidden: tourney.readOnly,
             tooltip: tprized
                 ? _('Reset assigned final prizes.')
@@ -129,7 +129,7 @@ Ext.define('SoL.view.Ranking.Actions', {
                                         [_('Reset assigned final prizes.')]);
                                 } else {
                                     me.component.setWidth(me.component.initialConfig.width);
-                                    me.prizegivingAction.setText(_('Prize'));
+                                    me.prizegivingAction.setText(_('Assign prizes'));
                                     me.prizegivingAction.callEach(
                                         'setTooltip',
                                         [_('Assign final prizes.')]);
@@ -209,7 +209,6 @@ Ext.define('SoL.view.Ranking', {
                     })
                 ],
                 //remoteGroup: false,
-                readOnly: config.tourney.readOnly,
                 remoteSort: false,
                 saveChangesURL: '/bio/saveChanges',
                 sorters: [
