@@ -36,7 +36,7 @@ Ext.define('SoL.window.Login', {
             height: 100,
             html: [
                 '<a href="/lit" data-qtip="',
-                _('Go to the light HTML only interface...').replace(/"/g, '”'),
+                _('Go to the light HTML only interface…').replace(/"/g, '”'),
                 '" target="_blank">',
                 '  <img src="/static/images/logo.png"',
                 '       style="margin-top: 15px; margin-left: 20px; float: left;">',
