@@ -167,12 +167,21 @@ class ClubSpec(metaclass=Fixture):
         owner = PlayerData.lele
 
 
+class ChampionshipPrev(metaclass=Fixture):
+    class prev:
+        description = 'Previous championship'
+        club = ClubData.scr
+        closed = True
+        owner = PlayerData.lele
+
+
 class ChampionshipData(metaclass=Fixture):
     class current:
         description = 'Current championship'
         club = ClubData.scr
         closed = True
         owner = PlayerData.lele
+        previous = ChampionshipPrev.prev
 
     class next:
         description = 'Next championship'
