@@ -44,7 +44,7 @@ class TestDataViews(AuthenticatedTestCase):
         club = result['root'][0]
         self.assertEqual(club['description'],
                          ClubData.scr.description)
-        self.assertEqual(club['Championships'], 5)
+        self.assertEqual(club['Championships'], 6)
 
     def test_not_owned_club(self):
         from .. import ClubData
@@ -135,7 +135,7 @@ class TestDataViews(AuthenticatedTestCase):
         result = response.json
         self.assertEqual(result['success'], True)
         self.assertEqual(result['message'], "Ok")
-        self.assertEqual(result['count'], len(ChampionshipData.rows))
+        self.assertEqual(result['count'], len(ChampionshipData.rows)+1)
 
     def test_championship(self):
         from .. import ClubData, ChampionshipData
