@@ -194,6 +194,85 @@ class TestFinals(AuthenticatedTestCase):
         self.assertFalse(result['prized'])
 
 
+class TestFinalsSwap(AuthenticatedTestCase):
+    USERNAME = 'admin'
+    PASSWORD = 'admin'
+
+    def setUp(self):
+        import transaction
+        from os.path import dirname, join
+        from ...models import DBSession, Tourney
+        from ...models.bio import load_sol
+
+        s = DBSession()
+
+        fullname = join(dirname(dirname(__file__)), 'scr',
+                        'Campionato_CCM_2014_2015-2014-12-14+7.sol')
+        with transaction.manager:
+            tourneys, skipped = load_sol(s, fullname)
+            guid = tourneys[0].guid
+
+        s = DBSession()
+
+        tourney = s.query(Tourney).filter_by(guid=guid).one()
+        self.idtourney = tourney.idtourney
+
+    def test_final(self):
+        from metapensiero.sqlalchemy.proxy.json import py2json
+        from ...models import DBSession, Tourney
+
+        s = DBSession()
+
+        tourney = s.query(Tourney).get(self.idtourney)
+
+        self.assertFalse(tourney.prized)
+        self.assertFalse(tourney.finalturns)
+        self.assertEqual(tourney.currentturn, 7)
+        self.assertEqual(tourney.rankedturn, tourney.currentturn)
+
+        response = self.app.get('/tourney/finalTurn?idtourney=%d' % self.idtourney)
+        result = response.json
+        self.assertTrue(result['success'])
+        self.assertFalse(result['prized'])
+        self.assertEqual(result['currentturn'], 8)
+        self.assertTrue(result['finalturns'])
+
+        s = DBSession()
+
+        tourney = s.query(Tourney).get(self.idtourney)
+        finalmatches = [m for m in tourney.matches if m.final]
+        self.assertEqual(len(finalmatches), 1)
+
+        final = finalmatches[0]
+        self.assertEqual(final.competitor1.player1.firstname, 'Ayesh Nilan')
+        self.assertEqual(final.competitor2.player1.firstname, 'Suresh')
+
+        results = [('idmatch', dict(idmatch=final.idmatch, score1=4, score2=23))]
+        response = self.app.post('/bio/saveChanges', dict(modified_records=py2json(results),
+                                                          deleted_records=py2json([])))
+        self.assertTrue(response.json['success'])
+        self.assertEqual(response.json['message'], "Ok")
+
+        response = self.app.get('/tourney/updateRanking?idtourney=%d' % self.idtourney)
+        result = response.json
+        self.assertTrue(result['success'])
+        self.assertEqual(result['rankedturn'], result['currentturn'])
+        self.assertTrue(result['prized'])
+
+        response = self.app.get('/tourney/ranking?filter_idtourney=%d' % self.idtourney)
+        result = response.json
+        self.assertEqual(result['success'], True)
+        self.assertEqual(result['message'], "Ok")
+        self.assertEqual(result['count'], 17)
+        ranking = result['root']
+        first = ranking[0]
+        second = ranking[1]
+        self.assertEqual(first['prize'], 1000)
+        self.assertIn('Suresh', first['description'])
+        self.assertEqual(second['prize'], 900)
+        self.assertIn('Ayesh Nilan', second['description'])
+
+
 class TestPrizing(AuthenticatedTestCase):
     USERNAME = 'admin'
     PASSWORD = 'admin'
