@@ -377,7 +377,9 @@ def championships(request, results):
     finals=dict(hidden=True),
     finalturns=dict(hidden=True),
     finalkind=dict(hidden=True),
-    Prizes=dict(hidden=True),
+    Prizes=dict(hidden=True,
+                label=_championships_t.c.prizes.info['label'],
+                hint=_championships_t.c.prizes.info['hint']),
     Championship=dict(label=_championships_t.c.description.info['label'],
                       hint=_('Championship this tourney belongs to.'),
                       flex=3,
